/*
 * Backpack - Skyscanner's Design System
 *
 * Copyright 2016-2020 Skyscanner Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* @flow */

import React from 'react';
import { StyleSheet, View } from 'react-native';
import { storiesOf } from '@storybook/react-native';
import { spacingBase } from 'bpk-tokens/tokens/base.react.native';

import action from '../../storybook/addons/actions';
import CenterDecorator from '../../storybook/CenterDecorator';
import { StorySubheading } from '../../storybook/TextStyles';

import BpkSelect from './index';

const styles = StyleSheet.create({
  select: {
    marginBottom: spacingBase,
  },
});

storiesOf('react-native-bpk-component-select', module)
  .addDecorator(CenterDecorator)
  .add('docs:default', () => (
    <View>
      <StorySubheading>Normal</StorySubheading>
      <View style={styles.select}>
        <BpkSelect onPress={action('Select pressed')} label="Value" />
      </View>

      <StorySubheading>With image</StorySubheading>
      <View style={styles.select}>
        <BpkSelect onPress={action('Select pressed')} label="Value" showImage />
      </View>

      <StorySubheading>Valid</StorySubheading>
      <View style={styles.select}>
        <BpkSelect onPress={action('Select pressed')} label="Value" />
      </View>

      <StorySubheading>Disabled</StorySubheading>
      <View style={styles.select}>
        <BpkSelect onPress={action('Select pressed')} label="Value" disabled />
      </View>

      <StorySubheading>Invalid</StorySubheading>
      <BpkSelect
        onPress={action('Select pressed')}
        label="Value"
        valid={false}
        validationMessage="A value must be selected to continue"
      />
    </View>
  ))
  .add('extreme', () => (
    <View>
      <StorySubheading>Normal</StorySubheading>
      <View style={styles.select}>
        <BpkSelect
          onPress={action('Select pressed')}
          label="Value with a very very very very long title that is definitely going to run off the end"
        />
      </View>

      <StorySubheading>With image</StorySubheading>
      <View style={styles.select}>
        <BpkSelect
          onPress={action('Select pressed')}
          label="Value with a very very very very long title that is definitely going to run off the end"
          showImage
        />
      </View>

      <StorySubheading>Valid</StorySubheading>
      <View style={styles.select}>
        <BpkSelect
          onPress={action('Select pressed')}
          label="Value with a very very very very long title that is definitely going to run off the end"
          valid
        />
      </View>

      <StorySubheading>Invalid</StorySubheading>
      <BpkSelect
        onPress={action('Select pressed')}
        label="Value with a very very very very long title that is definitely going to run off the end"
        valid={false}
        validationMessage="A value must be selected to continue"
      />
    </View>
  ));
